Contributing
============

Contributions in the form of bug reports, feature requests, or pull requests are
welcome. For pull requests, please consider:

 * Write [a proper commit message][proper-commit] and keep the history clean.
 * Avoid unrelated formatting changes, they make it harder to identify
   functional changes in the diff.
 * You agree to license your contribution under the 3-clause BSD license.

[proper-commit]: http://tbaggery.com/2008/04/19/a-note-about-git-commit-messages.html
